@@ -1,5 +1,5 @@
 // CvsDirectory.java
-// $Id: CvsDirectory.java,v 1.61 1998/11/23 15:24:27 bmahe Exp $  
+// $Id: CvsDirectory.java,v 1.63 1999/03/23 10:19:48 bmahe Exp $  
 // (c) COPYRIGHT MIT and INRIA, 1997.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
@@ -192,13 +192,6 @@ public class CvsDirectory implements LRUAble, CVS {
 	entries.put(name, entry);
     }
 
-    /**
-     * Get or create a manager for the given directory.
-     * @return A CVS manager instance for the given directory.
-     * @exception CvsException If some CVS exception occured while creating
-     * or initializing the manager.
-     */
-
     public static Properties defprops = null;
 
     /**
@@ -360,6 +353,10 @@ public class CvsDirectory implements LRUAble, CVS {
 	return (entries != null) ? (CvsEntry) entries.get(filename) : null ;
     }
 
+    protected void removeFileEntry(String filename) {
+	entries.remove(filename);
+    }
+
     /**
      * Look for a sub-directory entry.
      * @param filename The name of the entry to look for.
@@ -1013,12 +1010,15 @@ public class CvsDirectory implements LRUAble, CVS {
 	commit(names, msg, env);
 	// Update all files status:
 	for (int i = 0 ; i < names.length; i++) {
-	    CvsEntry entry = getFileEntry(names[i]);
-	    if ( entry != null )
-		entry.setStatus(stamp, FILE_R);
-	    else
-		createFileEntry(stamp, names[i], FILE_R);
+	    removeFileEntry(names[i]);
 	}
+// 	for (int i = 0 ; i < names.length; i++) {
+// 	    CvsEntry entry = getFileEntry(names[i]);
+// 	    if ( entry != null )
+// 		entry.setStatus(stamp, FILE_R);
+// 	    else
+// 		createFileEntry(stamp, names[i], FILE_R);
+// 	}
     }
 
     /**
