@@ -1,5 +1,5 @@
 // CgiFrame.java
-// $Id: CgiFrame.java,v 1.6 1998/08/14 11:06:56 bmahe Exp $
+// $Id: CgiFrame.java,v 1.8 1999/03/26 16:26:31 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
@@ -15,6 +15,7 @@ import org.w3c.www.mime.* ;
 import org.w3c.jigsaw.http.* ;
 import org.w3c.www.http.*;
 import org.w3c.jigsaw.auth.AuthFilter;
+import org.w3c.util.ArrayDictionary;
 
 /**
  * Parsing the CGI output - The CGIHeaderHolder, to hold CGI headers.
@@ -247,6 +248,10 @@ public class CgiFrame extends HTTPFrame {
      * Attribute index - Turn the script in debug mode.
      */
     protected static int ATTR_CGI_DEBUG = -1;
+    /**
+     * Attribute index - Additional environment vars
+     */
+    protected static int ATTR_ENV = -1;
 
     static {
 	Attribute a   = null ;
@@ -287,6 +292,11 @@ public class CgiFrame extends HTTPFrame {
 				 , Boolean.FALSE
 				 , Attribute.EDITABLE);
 	ATTR_CGI_DEBUG = AttributeRegistry.registerAttribute(cls, a);
+	// The env attribute:
+	a = new PropertiesAttribute("environment"
+				    , null
+				    , Attribute.EDITABLE);
+	ATTR_ENV = AttributeRegistry.registerAttribute(cls, a) ;
     }
 
     /**
@@ -308,6 +318,10 @@ public class CgiFrame extends HTTPFrame {
 	return (String[]) getValue(ATTR_COMMAND, null) ;
     }
 
+    public ArrayDictionary getUserEnv() {
+	return (ArrayDictionary) getValue(ATTR_ENV, null);
+    }
+
     /**
      * Get the noheader flag.
      * @return The boolean value of the noheader flag.
@@ -500,7 +514,6 @@ public class CgiFrame extends HTTPFrame {
 	InetAddress sadr      = server.getInetAddress() ;
 	// Specified environment variables:
 	// We do not handle the following variables:
-	// - PATH_TRANSLATED: I don't understand it
 	// - REMOTE_IDENT: would require usage of IDENT protocol.
 	// Authentification type, if any:
 	String svalue = (String) request.getState(AuthFilter.STATE_AUTHTYPE);
@@ -551,6 +564,20 @@ public class CgiFrame extends HTTPFrame {
 	addEnv ("SERVER_PROTOCOL", request.getVersion(), env) ;
 	// Server software:
 	addEnv ("SERVER_SOFTWARE", server.getSoftware(), env) ;
+	if (getFileResource()!= null) {
+	    addEnv("PATH_TRANSLATED", 
+		   getFileResource().getFile().getAbsolutePath(), env);
+	}
+
+	//Add user env
+	ArrayDictionary uenv = getUserEnv();
+	if (uenv != null) {
+	    Enumeration names = uenv.keys();
+	    while (names.hasMoreElements()) {
+		String var = (String)names.nextElement();
+		addEnv(var, (String)uenv.get(var), env);
+	    }
+	}
 	// All other request fields, yeah, let's lose even more time:
 	Enumeration e = request.enumerateHeaderDescriptions(false);
 	while ( e.hasMoreElements() ) {
@@ -575,7 +602,7 @@ public class CgiFrame extends HTTPFrame {
 	    System.arraycopy(command, 0, run, 1, command.length);
 	    return Runtime.getRuntime().exec (run, aenv) ;
 	} else {
-	    return Runtime.getRuntime().exec (command, aenv) ;
+	    return Runtime.getRuntime().exec (command[0], aenv) ;
 	}
     }
 
