@@ -1,5 +1,5 @@
 // JigsawHttpServletRequest.java
-// $Id: JigsawHttpServletRequest.java,v 1.40 1998/10/26 11:56:13 bmahe Exp $
+// $Id: JigsawHttpServletRequest.java,v 1.42 1999/03/17 18:00:56 bmahe Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
@@ -126,7 +126,7 @@ public class JigsawHttpServletRequest implements HttpServletRequest {
 	    // URL encoded parameters:
 	    String query = request.getQueryString();
 	    if (query != null) {
-		InputStream qis = new StringBufferInputStream(query);
+		Reader qis = new StringReader(query);
 		try {
 		    queryParameters = new URLDecoder(qis, false).parse();
 		} catch (Exception ex) {
@@ -168,7 +168,7 @@ public class JigsawHttpServletRequest implements HttpServletRequest {
 	Hashtable urlParameters = null;
 	String query = request.getQueryString();
 	if (query != null) {
-	    InputStream qis = new StringBufferInputStream(query);
+	    Reader qis = new StringReader(query);
 	    try {
 		urlParameters = new URLDecoder(qis, false).parse();
 		return (String) urlParameters.get(name);
@@ -281,6 +281,7 @@ public class JigsawHttpServletRequest implements HttpServletRequest {
      * Jigsaw realy has no notion of <em>translation</em> stricto
      * sensu (it has much better in fact ;-). This is a pain here.
      * @return Always <strong>null</strong>.
+     * @deprecated since jsdk1.2
      */
 
     public String getRealPath(String name) {
@@ -294,7 +295,7 @@ public class JigsawHttpServletRequest implements HttpServletRequest {
      * @exception IllegalStateException if getReader has been called on 
      * this same request. 
      * @exception IOException on other I/O related errors. 
-     * @see getReader
+     * @see JigsawHttpServletRequest#getReader
      */    
     public ServletInputStream getInputStream()
 	throws IOException
@@ -384,6 +385,14 @@ public class JigsawHttpServletRequest implements HttpServletRequest {
 	return request.getState(name);
     }
 
+    public void setAttribute(String name, Object object) {
+	request.setState(name, object);
+    }
+
+    public Enumeration getAttributeNames() {
+	return request.getStateNames();
+    }
+
     /**
      * HttpServletRequest implementation - Get the request's method.
      * @return A String instance.
@@ -673,6 +682,14 @@ public class JigsawHttpServletRequest implements HttpServletRequest {
 	return httpSession;
     }
 
+    /**
+     * Gets the current valid session associated with this request.
+     * @return the session associated with this request.
+     */
+    public HttpSession getSession() {
+	return getSession(true);
+    }
+
     protected String getCookieName() {
 	 ObservableProperties props =
 	     request.getClient().getServer().getProperties();
@@ -746,11 +763,23 @@ public class JigsawHttpServletRequest implements HttpServletRequest {
      * by the getSession method.)
      * @return true if the session id specified by the request for this 
      * session came in as part of the URL; false otherwise
+     * @deprecated since jsdk2.1
      */
     public boolean isRequestedSessionIdFromUrl() {
 	return (getRequestedSessionIdFromURL() != null);
     }
 
+    /**
+     * Checks whether the session id specified by this request came in as 
+     * part of the URL. (The requested session may not be the one returned 
+     * by the getSession method.)
+     * @return true if the session id specified by the request for this 
+     * session came in as part of the URL; false otherwise
+     */
+    public boolean isRequestedSessionIdFromURL() {
+	return (getRequestedSessionIdFromURL() != null);
+    }
+
     protected BufferedReader reader = null;
 
     /**
@@ -761,7 +790,7 @@ public class JigsawHttpServletRequest implements HttpServletRequest {
      * @exception IllegalStateException if getInputStream has been called on 
      * this same request. 
      * @exception IOException on other I/O related errors. 
-     * @see getInputStream 
+     * @see JigsawHttpServletRequest#getInputStream 
      */
     public BufferedReader getReader()
 	throws IOException
@@ -776,6 +805,13 @@ public class JigsawHttpServletRequest implements HttpServletRequest {
 	return reader;
     }
 
+    /**
+     * @@FIXME
+     */
+    protected Request getRequest() {
+	return request;
+    }
+
     JigsawHttpServletRequest(Servlet servlet, 
 			     Request request, 
 			     JigsawHttpServletResponse response,
