@@ -1,5 +1,5 @@
 // HttpReplyMessage.java
-// $Id: HttpReplyMessage.java,v 1.19 1998/08/13 16:28:18 bmahe Exp $
+// $Id: HttpReplyMessage.java,v 1.26 1999/03/17 18:06:17 bmahe Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
@@ -12,17 +12,17 @@ import org.w3c.www.mime.*;
 
 public class HttpReplyMessage extends HttpEntityMessage {
     // HTTP Reply message well-known headers
-    public static int H_ACCEPT_RANGES       = 46;
-    public static int H_AGE                 = 47;
-    public static int H_LOCATION            = 48;
-    public static int H_PROXY_AUTHENTICATE  = 49;
-    public static int H_PUBLIC              = 50;
-    public static int H_RETRY_AFTER         = 51;
-    public static int H_SERVER              = 52;
-    public static int H_VARY                = 53;
-    public static int H_WARNING             = 54;
-    public static int H_WWW_AUTHENTICATE    = 55;
-
+    public static int H_ACCEPT_RANGES       = 50;
+    public static int H_AGE                 = 51;
+    public static int H_LOCATION            = 52;
+    public static int H_PROXY_AUTHENTICATE  = 53;
+    public static int H_PUBLIC              = 54;
+    public static int H_RETRY_AFTER         = 55;
+    public static int H_SERVER              = 56;
+    public static int H_VARY                = 57;
+    public static int H_WARNING             = 58;
+    public static int H_WWW_AUTHENTICATE    = 59;
+    public static int H_AUTHENTICATION_INFO = 60;
 
     static {
 	registerHeader("Accept-Ranges"
@@ -56,9 +56,12 @@ public class HttpReplyMessage extends HttpEntityMessage {
 	registerHeader("Warning"
 		       , "org.w3c.www.http.HttpWarningList"
 		       , H_WARNING);
-	registerHeader("WWW-authenticate"
+	registerHeader("WWW-Authenticate"
 		       , "org.w3c.www.http.HttpChallenge"
 		       , H_WWW_AUTHENTICATE);
+	registerHeader("Authentication-Info"
+		       , "org.w3c.www.http.HttpParamList"
+		       , H_AUTHENTICATION_INFO);
     }
 
     /**
@@ -87,7 +90,7 @@ public class HttpReplyMessage extends HttpEntityMessage {
 	buf.append(' ');
 	buf.appendInt(status);
 	buf.append(' ');
-	buf.append((reason != null) ? reason : "Unknowed Status Code");
+	buf.append((reason != null) ? reason : "Unknown Status Code");
 	buf.append('\r');
 	buf.append('\n');
 	buf.emit(out);
@@ -606,6 +609,43 @@ public class HttpReplyMessage extends HttpEntityMessage {
     }
 
 
+    /**
+     * Get the Authentication Info (see digest auth) attached to this reply.
+     * @return An instance of HttpParamList, or <strong>null</strong> if
+     * undefined.
+     */
+
+    public HttpParamList getAuthenticationInfo() {
+	HeaderValue value = getHeaderValue(H_AUTHENTICATION_INFO);
+	return (value != null) ? (HttpParamList) value.getValue() : null;
+    }
+
+    /**
+     * Attach Authentication Info to this reply.
+     * @param plist, the parameter list to be attached to the reply, or
+     * <strong>null</strong> to reset the value.
+     */
+
+    public void setAuthenticationInfo(HttpParamList plist) {
+	setHeaderValue(H_AUTHENTICATION_INFO, plist);
+    }
+
+    /**
+     * Add the given parameter/value pair to the Authentication Info
+     * header
+     * @param String the name of the value
+     * @param String the value
+     */
+    
+    public void addAuthenticationInfo(String name, String value) {
+	HttpParamList hpl = getAuthenticationInfo();
+	if (hpl == null) {
+	    setAuthenticationInfo(hpl = new HttpParamList(true));
+	}
+	hpl.setParameter(name, value);
+    }
+	
+
     public HttpReplyMessage(MimeParser parser) {
 	super(parser);
     }
